# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/extension_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/elasticsearch/v1/extension_service.proto',
  package='yandex.cloud.mdb.elasticsearch.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9yandex/cloud/mdb/elasticsearch/v1/extension_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x31yandex/cloud/mdb/elasticsearch/v1/extension.proto\x1a&yandex/cloud/operation/operation.proto\"S\n\x13GetExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"w\n\x15ListExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n\x16ListExtensionsResponse\x12@\n\nextensions\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.Extension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\x16\x44\x65leteExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17\x44\x65leteExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"f\n\x16UpdateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\"W\n\x17UpdateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"{\n\x16\x43reateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\x03uri\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\"W\n\x17\x43reateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xc5\x08\n\x10\x45xtensionService\x12\xbe\x01\n\x03Get\x12\x36.yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest\x1a,.yandex.cloud.mdb.elasticsearch.v1.Extension\"Q\x82\xd3\xe4\x93\x02K\x12I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\x12\xbf\x01\n\x04List\x12\x38.yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest\x1a\x39.yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/managed-elasticsearch/v1/clusters/{cluster_id}/extensions\x12\xd5\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02?\":/managed-elasticsearch/v1/clusters/{cluster_id}/extensions:\x01*\xb2\xd2*$\n\x17\x43reateExtensionMetadata\x12\tExtension\x12\xe4\x01\n\x06Update\x12\x39.yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"|\x82\xd3\xe4\x93\x02N2I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\x01*\xb2\xd2*$\n\x17UpdateExtensionMetadata\x12\tExtension\x12\xee\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\x82\xd3\xe4\x93\x02K*I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\xb2\xd2*0\n\x17\x44\x65leteExtensionMetadata\x12\x15google.protobuf.EmptyB|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])




_GETEXTENSIONREQUEST = _descriptor.Descriptor(
  name='GetExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=365,
)


_LISTEXTENSIONSREQUEST = _descriptor.Descriptor(
  name='ListExtensionsRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=486,
)


_LISTEXTENSIONSRESPONSE = _descriptor.Descriptor(
  name='ListExtensionsResponse',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extensions', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse.extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=603,
)


_DELETEEXTENSIONREQUEST = _descriptor.Descriptor(
  name='DeleteExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=691,
)


_DELETEEXTENSIONMETADATA = _descriptor.Descriptor(
  name='DeleteExtensionMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=780,
)


_UPDATEEXTENSIONREQUEST = _descriptor.Descriptor(
  name='UpdateExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest.active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=884,
)


_UPDATEEXTENSIONMETADATA = _descriptor.Descriptor(
  name='UpdateExtensionMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=886,
  serialized_end=973,
)


_CREATEEXTENSIONREQUEST = _descriptor.Descriptor(
  name='CreateExtensionRequest',
  full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest.disabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1098,
)


_CREATEEXTENSIONMETADATA = _descriptor.Descriptor(
  name='CreateExtensionMetadata',
  full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_id', full_name='yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata.extension_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1100,
  serialized_end=1187,
)

_LISTEXTENSIONSRESPONSE.fields_by_name['extensions'].message_type = yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2._EXTENSION
DESCRIPTOR.message_types_by_name['GetExtensionRequest'] = _GETEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['ListExtensionsRequest'] = _LISTEXTENSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListExtensionsResponse'] = _LISTEXTENSIONSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteExtensionRequest'] = _DELETEEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteExtensionMetadata'] = _DELETEEXTENSIONMETADATA
DESCRIPTOR.message_types_by_name['UpdateExtensionRequest'] = _UPDATEEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateExtensionMetadata'] = _UPDATEEXTENSIONMETADATA
DESCRIPTOR.message_types_by_name['CreateExtensionRequest'] = _CREATEEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateExtensionMetadata'] = _CREATEEXTENSIONMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetExtensionRequest = _reflection.GeneratedProtocolMessageType('GetExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest)
  })
_sym_db.RegisterMessage(GetExtensionRequest)

ListExtensionsRequest = _reflection.GeneratedProtocolMessageType('ListExtensionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXTENSIONSREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest)
  })
_sym_db.RegisterMessage(ListExtensionsRequest)

ListExtensionsResponse = _reflection.GeneratedProtocolMessageType('ListExtensionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXTENSIONSRESPONSE,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse)
  })
_sym_db.RegisterMessage(ListExtensionsResponse)

DeleteExtensionRequest = _reflection.GeneratedProtocolMessageType('DeleteExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest)
  })
_sym_db.RegisterMessage(DeleteExtensionRequest)

DeleteExtensionMetadata = _reflection.GeneratedProtocolMessageType('DeleteExtensionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXTENSIONMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionMetadata)
  })
_sym_db.RegisterMessage(DeleteExtensionMetadata)

UpdateExtensionRequest = _reflection.GeneratedProtocolMessageType('UpdateExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest)
  })
_sym_db.RegisterMessage(UpdateExtensionRequest)

UpdateExtensionMetadata = _reflection.GeneratedProtocolMessageType('UpdateExtensionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXTENSIONMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionMetadata)
  })
_sym_db.RegisterMessage(UpdateExtensionMetadata)

CreateExtensionRequest = _reflection.GeneratedProtocolMessageType('CreateExtensionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXTENSIONREQUEST,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest)
  })
_sym_db.RegisterMessage(CreateExtensionRequest)

CreateExtensionMetadata = _reflection.GeneratedProtocolMessageType('CreateExtensionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXTENSIONMETADATA,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.CreateExtensionMetadata)
  })
_sym_db.RegisterMessage(CreateExtensionMetadata)


DESCRIPTOR._options = None
_GETEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_GETEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
_LISTEXTENSIONSREQUEST.fields_by_name['cluster_id']._options = None
_LISTEXTENSIONSREQUEST.fields_by_name['page_size']._options = None
_LISTEXTENSIONSREQUEST.fields_by_name['page_token']._options = None
_DELETEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_DELETEEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
_DELETEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
_DELETEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
_UPDATEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
_UPDATEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
_UPDATEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
_CREATEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
_CREATEEXTENSIONREQUEST.fields_by_name['name']._options = None
_CREATEEXTENSIONREQUEST.fields_by_name['uri']._options = None
_CREATEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
_CREATEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None

_EXTENSIONSERVICE = _descriptor.ServiceDescriptor(
  name='ExtensionService',
  full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1190,
  serialized_end=2283,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Get',
    index=0,
    containing_service=None,
    input_type=_GETEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2._EXTENSION,
    serialized_options=b'\202\323\344\223\002K\022I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.List',
    index=1,
    containing_service=None,
    input_type=_LISTEXTENSIONSREQUEST,
    output_type=_LISTEXTENSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/managed-elasticsearch/v1/clusters/{cluster_id}/extensions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/managed-elasticsearch/v1/clusters/{cluster_id}/extensions:\001*\262\322*$\n\027CreateExtensionMetadata\022\tExtension',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002N2I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\001*\262\322*$\n\027UpdateExtensionMetadata\022\tExtension',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.elasticsearch.v1.ExtensionService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEEXTENSIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002K*I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\262\322*0\n\027DeleteExtensionMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSIONSERVICE)

DESCRIPTOR.services_by_name['ExtensionService'] = _EXTENSIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/downsampling.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/downsampling.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/monitoring/v3/downsampling.proto\x12\x1ayandex.cloud.monitoring.v3\"\xbd\x04\n\x0c\x44ownsampling\x12\x14\n\nmax_points\x18\x01 \x01(\x03H\x00\x12\x17\n\rgrid_interval\x18\x02 \x01(\x03H\x00\x12\x12\n\x08\x64isabled\x18\x03 \x01(\x08H\x00\x12R\n\x10grid_aggregation\x18\x04 \x01(\x0e\x32\x38.yandex.cloud.monitoring.v3.Downsampling.GridAggregation\x12H\n\x0bgap_filling\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.monitoring.v3.Downsampling.GapFilling\"\xd2\x01\n\x0fGridAggregation\x12 \n\x1cGRID_AGGREGATION_UNSPECIFIED\x10\x00\x12\x18\n\x14GRID_AGGREGATION_MAX\x10\x01\x12\x18\n\x14GRID_AGGREGATION_MIN\x10\x02\x12\x18\n\x14GRID_AGGREGATION_SUM\x10\x03\x12\x18\n\x14GRID_AGGREGATION_AVG\x10\x04\x12\x19\n\x15GRID_AGGREGATION_LAST\x10\x05\x12\x1a\n\x16GRID_AGGREGATION_COUNT\x10\x06\"o\n\nGapFilling\x12\x1b\n\x17GAP_FILLING_UNSPECIFIED\x10\x00\x12\x14\n\x10GAP_FILLING_NULL\x10\x01\x12\x14\n\x10GAP_FILLING_NONE\x10\x02\x12\x18\n\x14GAP_FILLING_PREVIOUS\x10\x03\x42\x06\n\x04modeBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
)



_DOWNSAMPLING_GRIDAGGREGATION = _descriptor.EnumDescriptor(
  name='GridAggregation',
  full_name='yandex.cloud.monitoring.v3.Downsampling.GridAggregation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_MAX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_MIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_SUM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_AVG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_LAST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRID_AGGREGATION_COUNT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=320,
  serialized_end=530,
)
_sym_db.RegisterEnumDescriptor(_DOWNSAMPLING_GRIDAGGREGATION)

_DOWNSAMPLING_GAPFILLING = _descriptor.EnumDescriptor(
  name='GapFilling',
  full_name='yandex.cloud.monitoring.v3.Downsampling.GapFilling',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_NULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_NONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAP_FILLING_PREVIOUS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=532,
  serialized_end=643,
)
_sym_db.RegisterEnumDescriptor(_DOWNSAMPLING_GAPFILLING)


_DOWNSAMPLING = _descriptor.Descriptor(
  name='Downsampling',
  full_name='yandex.cloud.monitoring.v3.Downsampling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_points', full_name='yandex.cloud.monitoring.v3.Downsampling.max_points', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_interval', full_name='yandex.cloud.monitoring.v3.Downsampling.grid_interval', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.monitoring.v3.Downsampling.disabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_aggregation', full_name='yandex.cloud.monitoring.v3.Downsampling.grid_aggregation', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gap_filling', full_name='yandex.cloud.monitoring.v3.Downsampling.gap_filling', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DOWNSAMPLING_GRIDAGGREGATION,
    _DOWNSAMPLING_GAPFILLING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='yandex.cloud.monitoring.v3.Downsampling.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=78,
  serialized_end=651,
)

_DOWNSAMPLING.fields_by_name['grid_aggregation'].enum_type = _DOWNSAMPLING_GRIDAGGREGATION
_DOWNSAMPLING.fields_by_name['gap_filling'].enum_type = _DOWNSAMPLING_GAPFILLING
_DOWNSAMPLING_GRIDAGGREGATION.containing_type = _DOWNSAMPLING
_DOWNSAMPLING_GAPFILLING.containing_type = _DOWNSAMPLING
_DOWNSAMPLING.oneofs_by_name['mode'].fields.append(
  _DOWNSAMPLING.fields_by_name['max_points'])
_DOWNSAMPLING.fields_by_name['max_points'].containing_oneof = _DOWNSAMPLING.oneofs_by_name['mode']
_DOWNSAMPLING.oneofs_by_name['mode'].fields.append(
  _DOWNSAMPLING.fields_by_name['grid_interval'])
_DOWNSAMPLING.fields_by_name['grid_interval'].containing_oneof = _DOWNSAMPLING.oneofs_by_name['mode']
_DOWNSAMPLING.oneofs_by_name['mode'].fields.append(
  _DOWNSAMPLING.fields_by_name['disabled'])
_DOWNSAMPLING.fields_by_name['disabled'].containing_oneof = _DOWNSAMPLING.oneofs_by_name['mode']
DESCRIPTOR.message_types_by_name['Downsampling'] = _DOWNSAMPLING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Downsampling = _reflection.GeneratedProtocolMessageType('Downsampling', (_message.Message,), {
  'DESCRIPTOR' : _DOWNSAMPLING,
  '__module__' : 'yandex.cloud.monitoring.v3.downsampling_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Downsampling)
  })
_sym_db.RegisterMessage(Downsampling)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/target_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/target_group_service.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/apploadbalancer/v1/target_group_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/apploadbalancer/v1/target_group.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8c\x01\n\x17ListTargetGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x18ListTargetGroupsResponse\x12\x43\n\rtarget_groups\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TargetGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x18\x44\x65leteTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x19\x44\x65leteTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\xca\x03\n\x18UpdateTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x38\n\x07targets\x18\x06 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19UpdateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x93\x03\n\x18\x43reateTargetGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x45.yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x38\n\x07targets\x18\x05 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19\x43reateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"t\n\x11\x41\x64\x64TargetsRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x07targets\x18\x02 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x06\x82\xc8\x31\x02>0\"-\n\x12\x41\x64\x64TargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"w\n\x14RemoveTargetsRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x07targets\x18\x02 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x06\x82\xc8\x31\x02>0\"0\n\x15RemoveTargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x87\x01\n ListTargetGroupOperationsRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListTargetGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xee\x0c\n\x12TargetGroupService\x12\xa7\x01\n\x03Get\x12\x36.yandex.cloud.apploadbalancer.v1.GetTargetGroupRequest\x1a,.yandex.cloud.apploadbalancer.v1.TargetGroup\":\x82\xd3\xe4\x93\x02\x34\x12\x32/apploadbalancer/v1/targetGroups/{target_group_id}\x12\xa5\x01\n\x04List\x12\x38.yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest\x1a\x39.yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /apploadbalancer/v1/targetGroups\x12\xbf\x01\n\x06\x43reate\x12\x39.yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"W\x82\xd3\xe4\x93\x02%\" /apploadbalancer/v1/targetGroups:\x01*\xb2\xd2*(\n\x19\x43reateTargetGroupMetadata\x12\x0bTargetGroup\x12\xd1\x01\n\x06Update\x12\x39.yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x37\x32\x32/apploadbalancer/v1/targetGroups/{target_group_id}:\x01*\xb2\xd2*(\n\x19UpdateTargetGroupMetadata\x12\x0bTargetGroup\x12\xd8\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.apploadbalancer.v1.DeleteTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"p\x82\xd3\xe4\x93\x02\x34*2/apploadbalancer/v1/targetGroups/{target_group_id}\xb2\xd2*2\n\x19\x44\x65leteTargetGroupMetadata\x12\x15google.protobuf.Empty\x12\xd2\x01\n\nAddTargets\x12\x32.yandex.cloud.apploadbalancer.v1.AddTargetsRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x42\"=/apploadbalancer/v1/targetGroups/{target_group_id}:addTargets:\x01*\xb2\xd2*!\n\x12\x41\x64\x64TargetsMetadata\x12\x0bTargetGroup\x12\xde\x01\n\rRemoveTargets\x12\x35.yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/targetGroups/{target_group_id}:removeTargets:\x01*\xb2\xd2*$\n\x15RemoveTargetsMetadata\x12\x0bTargetGroup\x12\xde\x01\n\x0eListOperations\x12\x41.yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest\x1a\x42.yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/apploadbalancer/v1/targetGroups/{target_group_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETTARGETGROUPREQUEST = _descriptor.Descriptor(
  name='GetTargetGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetTargetGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.GetTargetGroupRequest.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=370,
)


_LISTTARGETGROUPSREQUEST = _descriptor.Descriptor(
  name='ListTargetGroupsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=513,
)


_LISTTARGETGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListTargetGroupsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_groups', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse.target_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=635,
)


_DELETETARGETGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteTargetGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteTargetGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteTargetGroupRequest.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=694,
)


_DELETETARGETGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteTargetGroupMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteTargetGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteTargetGroupMetadata.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=696,
  serialized_end=748,
)


_UPDATETARGETGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1209,
)

_UPDATETARGETGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateTargetGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.targets', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATETARGETGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=1209,
)


_UPDATETARGETGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateTargetGroupMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateTargetGroupMetadata.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1263,
)


_CREATETARGETGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1209,
)

_CREATETARGETGROUPREQUEST = _descriptor.Descriptor(
  name='CreateTargetGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.targets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATETARGETGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1669,
)


_CREATETARGETGROUPMETADATA = _descriptor.Descriptor(
  name='CreateTargetGroupMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.CreateTargetGroupMetadata.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1723,
)


_ADDTARGETSREQUEST = _descriptor.Descriptor(
  name='AddTargetsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.AddTargetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.AddTargetsRequest.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='yandex.cloud.apploadbalancer.v1.AddTargetsRequest.targets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1841,
)


_ADDTARGETSMETADATA = _descriptor.Descriptor(
  name='AddTargetsMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.AddTargetsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.AddTargetsMetadata.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1843,
  serialized_end=1888,
)


_REMOVETARGETSREQUEST = _descriptor.Descriptor(
  name='RemoveTargetsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest.targets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1890,
  serialized_end=2009,
)


_REMOVETARGETSMETADATA = _descriptor.Descriptor(
  name='RemoveTargetsMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveTargetsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveTargetsMetadata.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2059,
)


_LISTTARGETGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListTargetGroupOperationsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2197,
)


_LISTTARGETGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListTargetGroupOperationsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2199,
  serialized_end=2314,
)

_LISTTARGETGROUPSRESPONSE.fields_by_name['target_groups'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGETGROUP
_UPDATETARGETGROUPREQUEST_LABELSENTRY.containing_type = _UPDATETARGETGROUPREQUEST
_UPDATETARGETGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATETARGETGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATETARGETGROUPREQUEST_LABELSENTRY
_UPDATETARGETGROUPREQUEST.fields_by_name['targets'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGET
_CREATETARGETGROUPREQUEST_LABELSENTRY.containing_type = _CREATETARGETGROUPREQUEST
_CREATETARGETGROUPREQUEST.fields_by_name['labels'].message_type = _CREATETARGETGROUPREQUEST_LABELSENTRY
_CREATETARGETGROUPREQUEST.fields_by_name['targets'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGET
_ADDTARGETSREQUEST.fields_by_name['targets'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGET
_REMOVETARGETSREQUEST.fields_by_name['targets'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGET
_LISTTARGETGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetTargetGroupRequest'] = _GETTARGETGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListTargetGroupsRequest'] = _LISTTARGETGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListTargetGroupsResponse'] = _LISTTARGETGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTargetGroupRequest'] = _DELETETARGETGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteTargetGroupMetadata'] = _DELETETARGETGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateTargetGroupRequest'] = _UPDATETARGETGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateTargetGroupMetadata'] = _UPDATETARGETGROUPMETADATA
DESCRIPTOR.message_types_by_name['CreateTargetGroupRequest'] = _CREATETARGETGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateTargetGroupMetadata'] = _CREATETARGETGROUPMETADATA
DESCRIPTOR.message_types_by_name['AddTargetsRequest'] = _ADDTARGETSREQUEST
DESCRIPTOR.message_types_by_name['AddTargetsMetadata'] = _ADDTARGETSMETADATA
DESCRIPTOR.message_types_by_name['RemoveTargetsRequest'] = _REMOVETARGETSREQUEST
DESCRIPTOR.message_types_by_name['RemoveTargetsMetadata'] = _REMOVETARGETSMETADATA
DESCRIPTOR.message_types_by_name['ListTargetGroupOperationsRequest'] = _LISTTARGETGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListTargetGroupOperationsResponse'] = _LISTTARGETGROUPOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTargetGroupRequest = _reflection.GeneratedProtocolMessageType('GetTargetGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTARGETGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetTargetGroupRequest)
  })
_sym_db.RegisterMessage(GetTargetGroupRequest)

ListTargetGroupsRequest = _reflection.GeneratedProtocolMessageType('ListTargetGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTARGETGROUPSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest)
  })
_sym_db.RegisterMessage(ListTargetGroupsRequest)

ListTargetGroupsResponse = _reflection.GeneratedProtocolMessageType('ListTargetGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTARGETGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse)
  })
_sym_db.RegisterMessage(ListTargetGroupsResponse)

DeleteTargetGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteTargetGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETARGETGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteTargetGroupRequest)
  })
_sym_db.RegisterMessage(DeleteTargetGroupRequest)

DeleteTargetGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteTargetGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETETARGETGROUPMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteTargetGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteTargetGroupMetadata)

UpdateTargetGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateTargetGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATETARGETGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATETARGETGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest)
  })
_sym_db.RegisterMessage(UpdateTargetGroupRequest)
_sym_db.RegisterMessage(UpdateTargetGroupRequest.LabelsEntry)

UpdateTargetGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateTargetGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETARGETGROUPMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateTargetGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateTargetGroupMetadata)

CreateTargetGroupRequest = _reflection.GeneratedProtocolMessageType('CreateTargetGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATETARGETGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATETARGETGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest)
  })
_sym_db.RegisterMessage(CreateTargetGroupRequest)
_sym_db.RegisterMessage(CreateTargetGroupRequest.LabelsEntry)

CreateTargetGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateTargetGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATETARGETGROUPMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateTargetGroupMetadata)
  })
_sym_db.RegisterMessage(CreateTargetGroupMetadata)

AddTargetsRequest = _reflection.GeneratedProtocolMessageType('AddTargetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTARGETSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddTargetsRequest)
  })
_sym_db.RegisterMessage(AddTargetsRequest)

AddTargetsMetadata = _reflection.GeneratedProtocolMessageType('AddTargetsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDTARGETSMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddTargetsMetadata)
  })
_sym_db.RegisterMessage(AddTargetsMetadata)

RemoveTargetsRequest = _reflection.GeneratedProtocolMessageType('RemoveTargetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVETARGETSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest)
  })
_sym_db.RegisterMessage(RemoveTargetsRequest)

RemoveTargetsMetadata = _reflection.GeneratedProtocolMessageType('RemoveTargetsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVETARGETSMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveTargetsMetadata)
  })
_sym_db.RegisterMessage(RemoveTargetsMetadata)

ListTargetGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListTargetGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTARGETGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListTargetGroupOperationsRequest)

ListTargetGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListTargetGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTARGETGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListTargetGroupOperationsResponse)


DESCRIPTOR._options = None
_GETTARGETGROUPREQUEST.fields_by_name['target_group_id']._options = None
_LISTTARGETGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTTARGETGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTTARGETGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTTARGETGROUPSREQUEST.fields_by_name['filter']._options = None
_DELETETARGETGROUPREQUEST.fields_by_name['target_group_id']._options = None
_UPDATETARGETGROUPREQUEST_LABELSENTRY._options = None
_UPDATETARGETGROUPREQUEST.fields_by_name['target_group_id']._options = None
_UPDATETARGETGROUPREQUEST.fields_by_name['name']._options = None
_UPDATETARGETGROUPREQUEST.fields_by_name['description']._options = None
_UPDATETARGETGROUPREQUEST.fields_by_name['labels']._options = None
_CREATETARGETGROUPREQUEST_LABELSENTRY._options = None
_CREATETARGETGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATETARGETGROUPREQUEST.fields_by_name['name']._options = None
_CREATETARGETGROUPREQUEST.fields_by_name['description']._options = None
_CREATETARGETGROUPREQUEST.fields_by_name['labels']._options = None
_ADDTARGETSREQUEST.fields_by_name['target_group_id']._options = None
_ADDTARGETSREQUEST.fields_by_name['targets']._options = None
_REMOVETARGETSREQUEST.fields_by_name['target_group_id']._options = None
_REMOVETARGETSREQUEST.fields_by_name['targets']._options = None
_LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['target_group_id']._options = None
_LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_TARGETGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='TargetGroupService',
  full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2317,
  serialized_end=3963,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETTARGETGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2._TARGETGROUP,
    serialized_options=b'\202\323\344\223\0024\0222/apploadbalancer/v1/targetGroups/{target_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTTARGETGROUPSREQUEST,
    output_type=_LISTTARGETGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /apploadbalancer/v1/targetGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATETARGETGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%\" /apploadbalancer/v1/targetGroups:\001*\262\322*(\n\031CreateTargetGroupMetadata\022\013TargetGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATETARGETGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002722/apploadbalancer/v1/targetGroups/{target_group_id}:\001*\262\322*(\n\031UpdateTargetGroupMetadata\022\013TargetGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETETARGETGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0024*2/apploadbalancer/v1/targetGroups/{target_group_id}\262\322*2\n\031DeleteTargetGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddTargets',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.AddTargets',
    index=5,
    containing_service=None,
    input_type=_ADDTARGETSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002B\"=/apploadbalancer/v1/targetGroups/{target_group_id}:addTargets:\001*\262\322*!\n\022AddTargetsMetadata\022\013TargetGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveTargets',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.RemoveTargets',
    index=6,
    containing_service=None,
    input_type=_REMOVETARGETSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002E\"@/apploadbalancer/v1/targetGroups/{target_group_id}:removeTargets:\001*\262\322*$\n\025RemoveTargetsMetadata\022\013TargetGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.apploadbalancer.v1.TargetGroupService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTTARGETGROUPOPERATIONSREQUEST,
    output_type=_LISTTARGETGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/apploadbalancer/v1/targetGroups/{target_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TARGETGROUPSERVICE)

DESCRIPTOR.services_by_name['TargetGroupService'] = _TARGETGROUPSERVICE

# @@protoc_insertion_point(module_scope)
